
# fuzzer-cov

fuzzer coverage tool, generate readable coverage report in html format

## Prerequisite: Install lcov package

on ubuntu:

```shell
apt-get install lcov
```

## Installation

```shell
python3 -m pip install fuzzer-cov
```
